@@ -18,7 +18,7 @@ try:
 except ImportError:
     from urllib import unquote
 
-__version__ = "0.5.7"
+__version__ = "0.5.8"
 
 def listdir(directory):
 
@@ -107,7 +107,7 @@ class Client(object):
     def bar_thermometer(self, current, total, width=80):
         avail_dots = width-2
         shaded_dots = int(math.floor(float(current) / total * avail_dots))
-        return '[' + '.'*shaded_dots + ' '*(avail_dots-shaded_dots) + ']'
+        return '[' + '='*(shaded_dots-1) + '>' + ' '*(avail_dots-shaded_dots) + ']'
 
     def default_progress(self, current, total, width=80):
 
@@ -143,7 +143,7 @@ class Client(object):
                 output += self.bar_thermometer(current=current, total=total, width=min_width['bar']+avail)
             elif field == 'size':
                 # size field has a constant width (min == max)
-                output += ("%s / %s" % (current, total)).rjust(min_width['size'])
+                output += ("%s / %s" % (current, total)).rjust(min_width['size']-1)
 
             selected = selected[1:]
             if selected:
